@@ -1,9 +1,12 @@
-# IMPORTS
+"""A ``tesliper``'s main data storage."""
 import logging as lgg
-from collections import Counter, ItemsView, KeysView, OrderedDict, ValuesView
+from collections import Counter, OrderedDict
+from collections.abc import ItemsView, KeysView, ValuesView
 from contextlib import contextmanager
+from inspect import Parameter
 from itertools import chain
-from typing import Iterable, Optional, Sequence, Union
+from reprlib import recursive_repr
+from typing import Callable, Iterable, Optional, Sequence, Union
 
 import numpy as np
 
@@ -120,29 +123,18 @@ class Conformers(OrderedDict):
     said file's name. Its values are dictionaries with genres name (as key)
     and appropriate data pairs. Beside this, its essential functionality is
     transformation of stored data to corresponding DataArray objects with
-    use of `arrayed` method. It provides some control over this transformation,
+    use of :meth:`.arrayed` method. It provides some control over this transformation,
     especially in terms of including/excluding particular conformers' data
     on creation of new DataArray instance. This type of control is here called
-    trimming. Trimming can be achieved by use of various `trim` methods defined
-    in this class or by direct changes to `kept` attribute. See its
+    trimming. Trimming can be achieved by use of various *trim* methods defined
+    in this class or by direct changes to :attr:`.kept` attribute. See its
     documentation for more information.
 
-    Parameters
+    Attributes
     ----------
-    *args
-        list of arguments for creation of underlying dictionary
-    allow_data_inconsistency : bool, optional
-        specifies if data inconsistency should be allowed in created DataArray
-        object instances, defaults to False
-    **kwargs
-        list of arbitrary keyword arguments for creation of underlying
-        dictionary
-
-    Class Attributes
-    ----------------
     primary_genres
-        Data genres considered most important, used as default when checking
-        for conformers completeness (see `trim_incomplete` method).
+        Class attribute. Data genres considered most important, used as default when
+        checking for conformers completeness (see :meth:`.trim_incomplete` method).
 
     Notes
     -----
@@ -153,20 +145,80 @@ class Conformers(OrderedDict):
         "dip rot vosc vrot losc lrot raman1 roa1 scf zpe ent ten gib".split()
     )
 
-    def __init__(self, *args, allow_data_inconsistency=False, **kwargs):
+    def __init__(
+        self,
+        *args,
+        allow_data_inconsistency: bool = False,
+        temperature_of_the_system: float = 298.15,
+        **kwargs,
+    ):
+        """
+        Parameters
+        ----------
+        *args
+            list of arguments for creation of underlying dictionary
+        allow_data_inconsistency : bool, optional
+            specifies if data inconsistency should be allowed in created DataArray
+            object instances, defaults to False
+        temperature_of_the_system : float, optional
+            Temperature of the system in Kelvin units, must be zero or higher.
+            Defaults to room temperature = 298.15 K.
+        **kwargs
+            list of arbitrary keyword arguments for creation of underlying
+            dictionary
+        """
         self.allow_data_inconsistency = allow_data_inconsistency
+        self.temperature = temperature_of_the_system
         self.kept = []
         self.filenames = []
         self._indices = {}
         super().__init__(*args, **kwargs)
 
+    @property
+    def temperature(self) -> float:
+        """Temperature of the system expressed in Kelvin units.
+
+        Value of this parameter is passed to :term:`data array`\\s created with the
+        :meth:`.arrayed` method, provided that the target data array class supports a
+        parameter named *t* in it's constructor.
+
+        .. versionadded:: 0.9.1
+
+        Raises
+        ------
+        ValueError
+            if set to a value lower than zero.
+        """
+        return vars(self)["temperature"]
+
+    @temperature.setter
+    def temperature(self, value):
+        if value <= 0:
+            raise ValueError(
+                "Temperature of the system must be higher than absolute zero."
+            )
+        vars(self)["temperature"] = value
+
     def clear(self):
         """Remove all items from the Conformers instance."""
         self._kept = []
         self.filenames = []
         self._indices = {}
+        self.temperature = 298.15
         super().clear()
 
+    @recursive_repr()
+    def __repr__(self) -> str:
+        if not self:
+            return (
+                f"{self.__class__.__name__}("
+                f"allow_data_inconsistency={self.allow_data_inconsistency})"
+            )
+        return (
+            f"{self.__class__.__name__}({list(self.items())}, "
+            f"allow_data_inconsistency={self.allow_data_inconsistency})"
+        )
+
     def __setitem__(self, key, value):
         try:
             value = dict(value)
@@ -192,11 +244,45 @@ class Conformers(OrderedDict):
         for index, key in enumerate(self.keys()):
             self._indices[key] = index
 
+    def popitem(self, last=True):
+        """Remove and return a (key, value) pair from the dictionary.
+
+        Pairs are returned in LIFO order if last is true or FIFO order if false.
+        """
+        idx = -1 if last else 0
+        try:
+            key = self.filenames[idx]
+            return key, self.pop(key)
+        except IndexError:
+            raise KeyError("Conforemres is empty.")
+
+    def move_to_end(self, key, last=True):
+        """Move an existing element to the end (or beginning if last==False).
+
+        Raises KeyError if the element does not exist.
+        """
+        idx = self.index_of(key)
+        new_idx = 0 if not last else len(self.filenames) - 1
+        super().move_to_end(key, last)
+        self.filenames.insert(new_idx, self.filenames.pop(idx))
+        self._kept.insert(new_idx, self._kept.pop(idx))
+        self._indices = {k: i for i, k in enumerate(self.filenames)}
+
+    def copy(self):
+        "conformers.copy() -> a shallow copy of conformers"
+        cp = self.__class__(
+            allow_data_inconsistency=self.allow_data_inconsistency,
+            temperature_of_the_system=self.temperature,
+            **self,
+        )
+        cp.kept = self.kept
+        return cp
+
     @property
     def kept(self):
         """List of booleans, one for each conformer stored, defining if
         particular conformers data should be included in corresponding DataArray
-        instance, created by `arrayed` method. It may be changed by use of trim
+        instance, created by :meth:`.arrayed` method. It may be changed by use of trim
         methods, by setting its value directly, or by modification of the
         underlying list. For the first option refer to those methods
         documentation, for rest see the Examples section.
@@ -227,7 +313,7 @@ class Conformers(OrderedDict):
 
         New list of values can be set in a few ways. Firstly, it is the
         most straightforward to just assign a new list of boolean values to
-        the `kept` attribute. This list should have the same number of elements
+        the :attr:`.kept` attribute. This list should have the same number of elements
         as the number of conformers contained. A ValueError is raised if it
         doesn't.
 
@@ -255,9 +341,9 @@ class Conformers(OrderedDict):
         ...
         KeyError: Unknown conformers: other.
 
-        Thirdly, list of integers representing conformers indices may br given.
+        Thirdly, list of integers representing conformers indices may be given.
         Only conformers with specified indices will be kept. If one of given integers
-        cant be translated to conformer's index, IndexError is raised. Indexing with
+        can't be translated to conformer's index, IndexError is raised. Indexing with
         negative values is not supported currently.
 
         >>> c.kept = [1, 2]
@@ -268,8 +354,8 @@ class Conformers(OrderedDict):
         ...
         IndexError: Indexes out of bounds: 3.
 
-        Fourthly, assigning `True` or `False` to this attribute will mark all conformers
-        as kept or not kept respectively.
+        Fourthly, assigning ``True`` or ``False`` to this attribute will mark all
+        conformers as kept or not kept respectively.
 
         >>> c.kept = False
         >>> c.kept
@@ -280,8 +366,8 @@ class Conformers(OrderedDict):
 
         Lastly, list of kept values may be modified by setting its elements
         to True or False. It is advised against, however, as mistake such as
-        `m.kept[:2] = [True, False, False]` will break some functionality by
-        forcibly changing size of `kept` list.
+        ``c.kept[:2] = [True, False, False]`` will break some functionality by
+        forcibly changing size of :attr:`.kept` list.
 
         Notes
         -----
@@ -335,7 +421,7 @@ class Conformers(OrderedDict):
             )
 
     def update(self, other=None, **kwargs):
-        """Works like `dict.update`, but if key is already present, it updates
+        """Works like ``dict.update``, but if key is already present, it updates
         dictionary associated with given key rather than assigning new value.
         Keys of dictionary passed as positional parameter (or additional keyword
         arguments given) should be conformers' identifiers and its values should be
@@ -356,8 +442,13 @@ class Conformers(OrderedDict):
             else:
                 self[key] = value
 
-    def arrayed(self, genre: str, full: bool = False, **kwargs) -> AnyArray:
-        """Lists requested data and returns as appropriate `DataArray` instance.
+    def arrayed(
+        self, genre: str, full: bool = False, strict: bool = True, **kwargs
+    ) -> AnyArray:
+        """Lists requested data and returns as appropriate :class:`.DataArray` instance.
+
+        .. versionadded:: 0.9.1
+            The *strict* parameter.
 
         Parameters
         ----------
@@ -365,7 +456,11 @@ class Conformers(OrderedDict):
             String representing data genre. Must be one of known genres.
         full
             Boolean indicating if full set of data should be taken, ignoring
-            any trimming conducted earlier. Defaults to `False`.
+            any trimming conducted earlier. Defaults to ``False``.
+        strict
+            Boolean indicating if additional kwargs that doesn't match signature of data
+            array's constructor should cause an exception as normally (``strict =
+            True``) or be silently ignored (``strict = False``). Defaults to ``True``.
         kwargs
             Additional keyword parameters passed to data array constructor.
             Any explicitly given parameters will take precedence over automatically
@@ -374,7 +469,11 @@ class Conformers(OrderedDict):
         Returns
         -------
         DataArray
-            Arrayed data of desired genre as appropriate `DataArray` object.
+            Arrayed data of desired genre as appropriate :class:`.DataArray` object.
+
+        Notes
+        -----
+        For now, the special "filenames" genre always ignores *kwargs*.
         """
         try:
             cls = _ARRAY_CONSTRUCTORS[genre]  # ArrayBase subclasses
@@ -384,7 +483,7 @@ class Conformers(OrderedDict):
             # return early if filenames requested
             return cls(
                 genre=genre,
-                filenames=list(self.kept_values() if not full else self.values()),
+                filenames=list(self.kept_keys() if not full else self.keys()),
                 allow_data_inconsistency=self.allow_data_inconsistency,
             )
         view = self.kept_items() if not full else self.items()
@@ -398,38 +497,50 @@ class Conformers(OrderedDict):
                 f"Returning an empty array."
             )
             filenames, confs, values = [], [], []
-        params = cls.get_init_params()
-        parameter_type = type(params["genre"])
-        params["genre"] = genre
-        params["filenames"] = filenames
-        params["values"] = values
-        params["allow_data_inconsistency"] = self.allow_data_inconsistency
-        for key, value in params.items():
+        default_params = cls.get_init_params()
+        default_params["genre"] = genre
+        default_params["filenames"] = filenames
+        default_params["values"] = values
+        default_params["allow_data_inconsistency"] = self.allow_data_inconsistency
+        init_params = {}
+        for key, value in default_params.items():
             if key in kwargs:
                 # explicitly given keyword parameters take precedence
+                init_params[key] = kwargs.pop(key)
                 continue
-            if not isinstance(params[key], parameter_type):
+            if key == "t":
+                # if not given explicitly, temperature is taken form self
+                init_params[key] = self.temperature
+                continue
+            if not isinstance(default_params[key], Parameter):
                 # if value for parameter is already established, just take it
-                kwargs[key] = value
+                init_params[key] = value
                 continue
+            param_genre = (  # maybe ``key`` is not a param's genre name
+                value.genre_getter(genre) if hasattr(value, "genre_getter") else key
+            )
             try:
-                kwargs[key] = [conf[key] for conf in confs]
+                init_params[key] = [conf[param_genre] for conf in confs]
             except KeyError:
-                # set param to its default value
-                # or raise an error if it don't have one
+                # can't retrieve ``param_genre`` data from each included conformer
+                # set param to its default value or raise an error if it don't have one
                 if value.default is not value.empty:
-                    kwargs[key] = value.default
+                    init_params[key] = value.default
                 else:
                     raise TesliperError(
-                        f"One or more conformers does not provide value for '{key}' "
-                        f"genre, needed to instantiate {cls.__name__} object. "
-                        "You may provide missing values as a keyword parameters to the "
-                        "`Conformers.arrayed()` method call."
+                        f"One or more conformers does not provide value for "
+                        f"'{param_genre}' genre, needed to instantiate {cls.__name__} "
+                        "object. You may provide missing values as a keyword parameters"
+                        " to the `Conformers.arrayed()` method call."
                     )
-            if not kwargs[key] and value.default is not value.empty:
+            if not init_params[key] and value.default is not value.empty:
                 # genre produces an empty array, but parameter has default value
-                kwargs[key] = value.default
-        return cls(**kwargs)
+                init_params[key] = value.default
+        if kwargs and strict:
+            # any kwargs not popped till now are not expected by the ``cls.__init__()``
+            # if ``strict`` handling requested, add them anyway to cause an exception
+            init_params.update(**kwargs)
+        return cls(**init_params)
 
     def by_index(self, index: int) -> dict:
         """Returns data for conformer on desired index."""
@@ -454,8 +565,8 @@ class Conformers(OrderedDict):
         genre : str
             Name of genre to test.
         ignore_trimming : bool
-            If all known conformers should be considered (`ignore_trimming = True`)
-            or only kept ones (`ignore_trimming = False`, default).
+            If all known conformers should be considered (``ignore_trimming = True``)
+            or only kept ones (``ignore_trimming = False``, default).
 
         Returns
         -------
@@ -479,8 +590,8 @@ class Conformers(OrderedDict):
         genres : iterable of str
             List of names of genres to test.
         ignore_trimming : bool
-            If all known conformers should be considered (`ignore_trimming = True`)
-            or only kept ones (`ignore_trimming = False`, default).
+            If all known conformers should be considered (``ignore_trimming = True``)
+            or only kept ones (``ignore_trimming = False``, default).
 
         Returns
         -------
@@ -504,8 +615,8 @@ class Conformers(OrderedDict):
         genres : iterable of str
             List of names of genres to test.
         ignore_trimming : bool
-            If all known conformers should be considered (`ignore_trimming = True`)
-            or only kept ones (`ignore_trimming = False`, default).
+            If all known conformers should be considered (``ignore_trimming = True``)
+            or only kept ones (``ignore_trimming = False``, default).
 
         Returns
         -------
@@ -524,26 +635,26 @@ class Conformers(OrderedDict):
     ) -> None:
         """Mark incomplete conformers as "not kept".
 
-        Conformers that does not contain one or more data genres specified as `wanted`
-        will be marked as "not kept". If `wanted` parameter is not given, it evaluates
-        to `conformers.primary_genres`. If no conformer contains all `wanted` genres,
+        Conformers that does not contain one or more data genres specified as *wanted*
+        will be marked as "not kept". If *wanted* parameter is not given, it evaluates
+        to :attr:`.primary_genres`. If no conformer contains all *wanted* genres,
         conformers that match the specification most closely are kept. The "closeness"
-        is defined by number of conformer's genres matching `wanted` genres in the first
-        place (the more, the better) and the position of particular genre in `wanted`
+        is defined by number of conformer's genres matching *wanted* genres in the first
+        place (the more, the better) and the position of particular genre in *wanted*
         list in the second place (the closer to the beginning, the better). This
         "match closest" behaviour may be turned off by setting parameter
-        `strict` to `True`. In such case, only conformers containing all `wanted`
+        *strict* to ``True``. In such case, only conformers containing all *wanted*
         genres will be kept.
 
         Parameters
         ----------
         wanted
             List of data genres used as completeness reference.
-            If not given, evaluates to `conformers.primary_genres`.
+            If not given, evaluates to :attr:`.primary_genres`.
         strict
-            Indicates if all `wanted` genres must be present in the kept conformers
-            (`strict=True`) or if "match closest" mechanism should be used
-            as a fallback (`strict=False`, this is the default).
+            Indicates if all *wanted* genres must be present in the kept conformers
+            (``strict=True``) or if "match closest" mechanism should be used
+            as a fallback (``strict=False``, this is the default).
 
         Notes
         -----
@@ -577,8 +688,8 @@ class Conformers(OrderedDict):
                 self._kept[index] = False
 
     def trim_non_matching_stoichiometry(self, wanted: Optional[str] = None) -> None:
-        """Mark all conformers with stoichiometry other than `wanted` as "not kept".
-        If not given, `wanted` evaluates to the most common stoichiometry.
+        """Mark all conformers with stoichiometry other than *wanted* as "not kept".
+        If not given, *wanted* evaluates to the most common stoichiometry.
 
         Parameters
         ----------
@@ -675,8 +786,8 @@ class Conformers(OrderedDict):
         attribute: str = "values",
     ) -> None:
         """Marks as "not kept" all conformers, which numeric value of data
-        of specified genre is outside of the range specified by `minimum`
-        and `maximum` values.
+        of specified genre is outside of the range specified by *minimum*
+        and *maximum* values.
 
         Parameters
         ----------
@@ -685,26 +796,26 @@ class Conformers(OrderedDict):
             minimum and maximum values.
         minimum
             Minimal accepted value - every conformer, which genre value evaluates
-            to less than `minimum` will be marked as "not kept".
-            Defaults to `float(-inf)`.
+            to less than *minimum* will be marked as "not kept".
+            Defaults to ``float(-inf)``.
         maximum
             Maximal accepted value - every conformer, which genre value evaluates
-            to more than `maximum` will be marked as "not kept".
-            Defaults to `float(inf)`.
+            to more than *maximum* will be marked as "not kept".
+            Defaults to ``float(inf)``.
         attribute
-            Attribute of DataArray of specified `genre` that contains one-dimensional
+            Attribute of DataArray of specified *genre* that contains one-dimensional
             array of numeric values. defaults to `"values"`.
 
         Raises
         ------
         AttributeError
-            If DataArray associated with `genre` genre has no attribute `attribute`.
+            If DataArray associated with *genre* genre has no attribute *attribute*.
         ValueError
             If data retrieved from specified genre's attribute is not in the form of
             one-dimensional array.
         TypeError
             If comparision cannot be made between elements of specified genre's
-            attribute and `minimum` or `maximum` values.
+            attribute and *minimum* or *maximum* values.
 
         Notes
         -----
@@ -735,24 +846,34 @@ class Conformers(OrderedDict):
     def trim_rmsd(
         self,
         threshold: Union[int, float],
-        window_size: Union[int, float],
-        geometry_genre: str = "geometry",
+        window_size: Optional[Union[int, float]],
+        geometry_genre: str = "last_read_geom",
         energy_genre: str = "scf",
         ignore_hydrogen: bool = True,
+        moving_window_strategy: Callable = dw.stretching_windows,
     ) -> None:
-        """Marks as "not kept" all conformers, that are not identical, according
-        to provided RMSD threshold and energy difference. Conformers, which energy
-        difference (dE) is higher than given `window_size` are always treated as
-        different, while those with dE smaller than `window_size` and RMSD value
-        smaller than given `threshold` are considered identical. From two identical
-        conformers, the one with lower energy is "kept", and the other is discarded
-        (marked as "not kept").
+        """Marks as "not kept" all conformers that are identical with some other
+        conformer, judging by a provided RMSD threshold.
+
+        To minimize computation cost, conformers are compared inside windows, that is a
+        subsets of the original list of conformers. Those windows are generated by the
+        *moving_window_strategy* function. The recommended strategy, and a default
+        value, is :func:`.streaching_windows`, but other are also available:
+        :func:`.fixed_windows` and :func:`.pyramid_windows`. This function will be
+        called with list of energies for conformers compared and (if it is not ``None``)
+        *window_size* parameter.
+
+        With default *moving_window_strategy* conformers, which energy difference (dE)
+        is higher than given *window_size* are always treated as different, while those
+        with dE smaller than *window_size* and RMSD value smaller than given *threshold*
+        are considered identical. From two identical conformers, the one with lower
+        energy is "kept", and the other is discarded (marked as "not kept").
 
         Notes
         -----
         RMSD threshold and size of the energy window should be chosen depending on the
         parameters of conformers' set: number of conformers, size of the conformer,
-        its lability, etc. However, `threshold` of 0.5 angstrom and `windoe_size`
+        its lability, etc. However, *threshold* of 0.5 angstrom and *window_size*
         of 5 to 10 kcal/mol is a good place to start if in doubt.
 
         Parameters
@@ -764,64 +885,72 @@ class Conformers(OrderedDict):
             calculated. Essentially, a difference in conformers' energy, after which
             conformers are always considered different.
         geometry_genre : str
-            Genre of geometry used to calculate RMSD matrix. "geometry" is default.
+            Genre of geometry used to calculate RMSD matrix. "last_read_geom" is
+            default.
         energy_genre : str
             Genre of energy used to sort and group conformers into windows of given
             energy size. "scf" is used by default.
         ignore_hydrogen : bool
             If hydrogen atom should be discarded before RMSD calculation.
-            Defaults to `True`.
+            Defaults to ``True``.
+        moving_window_strategy : callable
+            Function that generates windows, inside which RMSD comparisions is
+            performed.
 
         Raises
         ------
         InconsistentDataError
             If requested genres does not provide the same set of conformers.
         ValueError
-            When called with `ignore_hydrogen=True` but requested
-            `Geometry.molecule_atoms` cannot be collapsed to 1-D array.
+            When called with ``ignore_hydrogen=True`` but requested
+            :attr:`.Geometry.atoms` cannot be collapsed to 1-D array.
         """
         energy = self.arrayed(energy_genre)
         geometry = self.arrayed(geometry_genre)
         if not energy.filenames.size == geometry.filenames.size:
             raise InconsistentDataError(
                 "Unequal number of conformers in requested geometry and energy genres. "
-                "Trim incomplete entries before trimming with `trim_rmds`."
+                "Trim incomplete entries before trimming with :meth:`.trim_rmds`."
             )
         elif not np.array_equal(energy.filenames, geometry.filenames):
             raise InconsistentDataError(
                 "Different conformers in requested geometry and energy genres. "
-                "Trim incomplete entries before trimming with `trim_rmds`."
+                "Trim incomplete entries before trimming with :meth:`.trim_rmds`."
             )
         if not geometry:
             return  # next steps assume there are some conformers
-        if ignore_hydrogen and geometry.molecule_atoms.shape[0] > 1:
+        if ignore_hydrogen and geometry.atoms.shape[0] > 1:
             # TODO: remove when dw.geometry.select_atoms supplemented
             raise ValueError(
                 "Cannot ignore hydrogen atoms if requested conformers do not have "
                 "the same order of atoms. This functionality is not supported yet."
             )
         geom = (
-            dw.drop_atoms(geometry.values, geometry.molecule_atoms[0], dw.atoms.Atom.H)
+            dw.drop_atoms(geometry.values, geometry.atoms[0], dw.atoms.Atom.H)
             if ignore_hydrogen
             else geometry.values
         )
-        wanted = dw.rmsd_sieve(geom, energy.as_kcal_per_mol, window_size, threshold)
+        if window_size is None:
+            windows = moving_window_strategy(energy.as_kcal_per_mol)
+        else:
+            windows = moving_window_strategy(energy.as_kcal_per_mol, window_size)
+        wanted = dw.rmsd_sieve(geom, windows, threshold)
         self.kept = geometry.filenames[wanted]
 
     def select_all(self) -> None:
-        """Marks all conformers as 'kept'. Equivalent to `conformers.kept = True`."""
+        """Marks all conformers as 'kept'. Equivalent to ``conformers.kept = True``."""
         self._kept = [True for _ in self._kept]
 
     def reject_all(self) -> None:
         """Marks all conformers as 'not kept'. Equivalent to
-        `conformers.kept = False`.
+        ``conformers.kept = False``.
         """
         self._kept = [False for _ in self._kept]
 
     def kept_keys(self, indices: bool = False) -> _KeptKeysView:
-        """Equivalent of `dict.keys()` but gives view only on conformers marked
+        """Equivalent of ``dict.keys()`` but gives view only on conformers marked
         as "kept". Returned view may also provide information on conformers index
-        in its Conformers instance if requested with `indices=True`.
+        in its Conformers instance if requested with ``indices=True``.
 
         >>> c = Conformers(c1={"g": 0.1}, c2={"g": 0.2}, c3={"g": 0.3}}
         >>> c.kept = [True, False, True]
@@ -844,9 +973,9 @@ class Conformers(OrderedDict):
         return _KeptKeysView(self, indices=indices)
 
     def kept_values(self, indices: bool = False) -> _KeptValuesView:
-        """Equivalent of `dict.values()` but gives view only on conformers marked
+        """Equivalent of ``dict.values()`` but gives view only on conformers marked
         as "kept". Returned view may also provide information on conformers index
-        in its Conformers instance if requested with `indices=True`.
+        in its Conformers instance if requested with ``indices=True``.
 
         >>> c = Conformers(c1={"g": 0.1}, c2={"g": 0.2}, c3={"g": 0.3}}
         >>> c.kept = [True, False, True]
@@ -869,9 +998,9 @@ class Conformers(OrderedDict):
         return _KeptValuesView(self, indices=indices)
 
     def kept_items(self, indices: bool = False) -> _KeptItemsView:
-        """Equivalent of `dict.items()` but gives view only on conformers marked
+        """Equivalent of ``dict.items()`` but gives view only on conformers marked
         as "kept". Returned view may also provide information on conformers index
-        in its Conformers instance if requested with `indices=True`.
+        in its Conformers instance if requested with ``indices=True``.
 
         >>> c = Conformers(c1={"g": 0.1}, c2={"g": 0.2}, c3={"g": 0.3}}
         >>> c.kept = [True, False, True]
